#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 scotty
version:              0.22
visibility:           public
id:                   scotty-0.22-4t8N5i8XWSsHx5IL28vtRT
key:                  scotty-0.22-4t8N5i8XWSsHx5IL28vtRT
license:              BSD-3-Clause
copyright:            (c) 2012-Present, Andrew Farmer and the Scotty contributors
maintainer:           The Scotty maintainers
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- pathParam &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  7287c30b97c28f3211db1a7c992f897c
exposed:              True
exposed-modules:
    Web.Scotty Web.Scotty.Cookie Web.Scotty.Internal.Types
    Web.Scotty.Trans Web.Scotty.Trans.Strict

hidden-modules:
    Web.Scotty.Action Web.Scotty.Body Web.Scotty.Route
    Web.Scotty.Trans.Lazy Web.Scotty.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/scotty-0.22
library-dirs:         /usr/lib/ghc-9.6.6/site-local/scotty-0.22
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/scotty-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-scotty
hs-libraries:         HSscotty-0.22-4t8N5i8XWSsHx5IL28vtRT
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ base-4.18.2.1
    blaze-builder-0.4.4.1-LpEq21LNRHq8DXqqJhoUXc bytestring-0.11.5.3
    case-insensitive-1.2.1.0-5z8pg5dkh9iJJTZAXWxvrE
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc exceptions-0.10.7
    http-types-0.12.4-DqlJEFWTOko3HaGBL8m7t6
    monad-control-1.0.3.1-508UqqoKHYB7MgacTVJ2OO mtl-2.3.1
    network-3.1.4.0-DnyUe3C7n48FET4frYkCJy
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    resourcet-1.2.6-BTixKgkFAZ7Fh4PNhKyioS stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6.1-B6kTXgBk4zDI4GxLkJR9qf
    unliftio-0.2.25.1-48sGHGhS3Nb9ygO7gybAdR
    wai-3.2.4-4rXE4pO3B1rCpC3Hr94dpe
    wai-extra-3.1.18-GNt5X2XdXqs5TR6xaLgpsi
    warp-3.4.0-H1z1Wrsethw8cHLM85NCG

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

